==> zio-aws-redshift_2.13-5.17.130.6-sources.jar: zio/aws/redshift/model/ReservedNode.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.{Integer, TStamp}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class ReservedNode(
    reservedNodeId: Option[String] = None,
    reservedNodeOfferingId: Option[String] = None,
    nodeType: Option[String] = None,
    startTime: Option[TStamp] = None,
    duration: Option[Integer] = None,
    fixedPrice: Option[Double] = None,
    usagePrice: Option[Double] = None,
    currencyCode: Option[String] = None,
    nodeCount: Option[Integer] = None,
    state: Option[String] = None,
    offeringType: Option[String] = None,
    recurringCharges: Option[Iterable[zio.aws.redshift.model.RecurringCharge]] =
      None,
    reservedNodeOfferingType: Option[
      zio.aws.redshift.model.ReservedNodeOfferingType
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ReservedNode = {
    import ReservedNode.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ReservedNode
      .builder()
      .optionallyWith(reservedNodeId.map(value => value: java.lang.String))(
        _.reservedNodeId
      )
      .optionallyWith(
        reservedNodeOfferingId.map(value => value: java.lang.String)
      )(_.reservedNodeOfferingId)
      .optionallyWith(nodeType.map(value => value: java.lang.String))(
        _.nodeType
      )
      .optionallyWith(startTime.map(value => TStamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(duration.map(value => value: java.lang.Integer))(
        _.duration
      )
      .optionallyWith(fixedPrice.map(value => value: java.lang.Double))(
        _.fixedPrice
      )
      .optionallyWith(usagePrice.map(value => value: java.lang.Double))(
        _.usagePrice
      )
      .optionallyWith(currencyCode.map(value => value: java.lang.String))(
        _.currencyCode
      )
      .optionallyWith(nodeCount.map(value => value: java.lang.Integer))(
        _.nodeCount
      )
      .optionallyWith(state.map(value => value: java.lang.String))(_.state)
      .optionallyWith(offeringType.map(value => value: java.lang.String))(
        _.offeringType
      )
      .optionallyWith(
        recurringCharges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recurringCharges)
      .optionallyWith(reservedNodeOfferingType.map(value => value.unwrap))(
        _.reservedNodeOfferingType
      )
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.ReservedNode.ReadOnly =
    zio.aws.redshift.model.ReservedNode.wrap(buildAwsValue())
}
object ReservedNode {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ReservedNode
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ReservedNode =
      zio.aws.redshift.model.ReservedNode(
        reservedNodeId.map(value => value),
        reservedNodeOfferingId.map(value => value),
        nodeType.map(value => value),
        startTime.map(value => value),
        duration.map(value => value),
        fixedPrice.map(value => value),
        usagePrice.map(value => value),
        currencyCode.map(value => value),
        nodeCount.map(value => value),
        state.map(value => value),
        offeringType.map(value => value),
        recurringCharges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        reservedNodeOfferingType.map(value => value)
      )
    def reservedNodeId: Option[String]
    def reservedNodeOfferingId: Option[String]
    def nodeType: Option[String]
    def startTime: Option[TStamp]
    def duration: Option[Integer]
    def fixedPrice: Option[Double]
    def usagePrice: Option[Double]
    def currencyCode: Option[String]
    def nodeCount: Option[Integer]
    def state: Option[String]
    def offeringType: Option[String]
    def recurringCharges
        : Option[List[zio.aws.redshift.model.RecurringCharge.ReadOnly]]
    def reservedNodeOfferingType
        : Option[zio.aws.redshift.model.ReservedNodeOfferingType]
    def getReservedNodeId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("reservedNodeId", reservedNodeId)
    def getReservedNodeOfferingId: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("reservedNodeOfferingId", reservedNodeOfferingId)
    def getNodeType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nodeType", nodeType)
    def getStartTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getDuration: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("duration", duration)
    def getFixedPrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("fixedPrice", fixedPrice)
    def getUsagePrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("usagePrice", usagePrice)
    def getCurrencyCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("currencyCode", currencyCode)
    def getNodeCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("nodeCount", nodeCount)
    def getState: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("state", state)
    def getOfferingType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("offeringType", offeringType)
    def getRecurringCharges: ZIO[Any, AwsError, List[
      zio.aws.redshift.model.RecurringCharge.ReadOnly
    ]] = AwsError.unwrapOptionField("recurringCharges", recurringCharges)
    def getReservedNodeOfferingType
        : ZIO[Any, AwsError, zio.aws.redshift.model.ReservedNodeOfferingType] =
      AwsError.unwrapOptionField(
        "reservedNodeOfferingType",
        reservedNodeOfferingType
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ReservedNode
  ) extends zio.aws.redshift.model.ReservedNode.ReadOnly {
    override val reservedNodeId: Option[String] =
      scala.Option(impl.reservedNodeId()).map(value => value: String)
    override val reservedNodeOfferingId: Option[String] =
      scala.Option(impl.reservedNodeOfferingId()).map(value => value: String)
    override val nodeType: Option[String] =
      scala.Option(impl.nodeType()).map(value => value: String)
    override val startTime: Option[TStamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
    override val duration: Option[Integer] =
      scala.Option(impl.duration()).map(value => value: Integer)
    override val fixedPrice: Option[Double] =
      scala.Option(impl.fixedPrice()).map(value => value: Double)
    override val usagePrice: Option[Double] =
      scala.Option(impl.usagePrice()).map(value => value: Double)
    override val currencyCode: Option[String] =
      scala.Option(impl.currencyCode()).map(value => value: String)
    override val nodeCount: Option[Integer] =
      scala.Option(impl.nodeCount()).map(value => value: Integer)
    override val state: Option[String] =
      scala.Option(impl.state()).map(value => value: String)
    override val offeringType: Option[String] =
      scala.Option(impl.offeringType()).map(value => value: String)
    override val recurringCharges
        : Option[List[zio.aws.redshift.model.RecurringCharge.ReadOnly]] = scala
      .Option(impl.recurringCharges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.redshift.model.RecurringCharge.wrap(item)
        }.toList
      )
    override val reservedNodeOfferingType
        : Option[zio.aws.redshift.model.ReservedNodeOfferingType] = scala
      .Option(impl.reservedNodeOfferingType())
      .map(value => zio.aws.redshift.model.ReservedNodeOfferingType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ReservedNode
  ): zio.aws.redshift.model.ReservedNode.ReadOnly = new Wrapper(impl)
}

==> zio-aws-redshift_3-5.17.128.1-sources.jar: zio/aws/redshift/model/ReservedNode.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.{Integer, TStamp}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class ReservedNode(
    reservedNodeId: Option[String] = None,
    reservedNodeOfferingId: Option[String] = None,
    nodeType: Option[String] = None,
    startTime: Option[TStamp] = None,
    duration: Option[Integer] = None,
    fixedPrice: Option[Double] = None,
    usagePrice: Option[Double] = None,
    currencyCode: Option[String] = None,
    nodeCount: Option[Integer] = None,
    state: Option[String] = None,
    offeringType: Option[String] = None,
    recurringCharges: Option[Iterable[zio.aws.redshift.model.RecurringCharge]] =
      None,
    reservedNodeOfferingType: Option[
      zio.aws.redshift.model.ReservedNodeOfferingType
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ReservedNode = {
    import ReservedNode.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ReservedNode
      .builder()
      .optionallyWith(reservedNodeId.map(value => value: java.lang.String))(
        _.reservedNodeId
      )
      .optionallyWith(
        reservedNodeOfferingId.map(value => value: java.lang.String)
      )(_.reservedNodeOfferingId)
      .optionallyWith(nodeType.map(value => value: java.lang.String))(
        _.nodeType
      )
      .optionallyWith(startTime.map(value => TStamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(
        duration.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.duration)
      .optionallyWith(fixedPrice.map(value => value: java.lang.Double))(
        _.fixedPrice
      )
      .optionallyWith(usagePrice.map(value => value: java.lang.Double))(
        _.usagePrice
      )
      .optionallyWith(currencyCode.map(value => value: java.lang.String))(
        _.currencyCode
      )
      .optionallyWith(
        nodeCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.nodeCount)
      .optionallyWith(state.map(value => value: java.lang.String))(_.state)
      .optionallyWith(offeringType.map(value => value: java.lang.String))(
        _.offeringType
      )
      .optionallyWith(
        recurringCharges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recurringCharges)
      .optionallyWith(reservedNodeOfferingType.map(value => value.unwrap))(
        _.reservedNodeOfferingType
      )
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.ReservedNode.ReadOnly =
    zio.aws.redshift.model.ReservedNode.wrap(buildAwsValue())
}
object ReservedNode {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ReservedNode
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ReservedNode =
      zio.aws.redshift.model.ReservedNode(
        reservedNodeId.map(value => value),
        reservedNodeOfferingId.map(value => value),
        nodeType.map(value => value),
        startTime.map(value => value),
        duration.map(value => value),
        fixedPrice.map(value => value),
        usagePrice.map(value => value),
        currencyCode.map(value => value),
        nodeCount.map(value => value),
        state.map(value => value),
        offeringType.map(value => value),
        recurringCharges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        reservedNodeOfferingType.map(value => value)
      )
    def reservedNodeId: Option[String]
    def reservedNodeOfferingId: Option[String]
    def nodeType: Option[String]
    def startTime: Option[TStamp]
    def duration: Option[Integer]
    def fixedPrice: Option[Double]
    def usagePrice: Option[Double]
    def currencyCode: Option[String]
    def nodeCount: Option[Integer]
    def state: Option[String]
    def offeringType: Option[String]
    def recurringCharges
        : Option[List[zio.aws.redshift.model.RecurringCharge.ReadOnly]]
    def reservedNodeOfferingType
        : Option[zio.aws.redshift.model.ReservedNodeOfferingType]
    def getReservedNodeId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("reservedNodeId", reservedNodeId)
    def getReservedNodeOfferingId: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("reservedNodeOfferingId", reservedNodeOfferingId)
    def getNodeType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nodeType", nodeType)
    def getStartTime: ZIO[Any, AwsError, TStamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getDuration: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("duration", duration)
    def getFixedPrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("fixedPrice", fixedPrice)
    def getUsagePrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("usagePrice", usagePrice)
    def getCurrencyCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("currencyCode", currencyCode)
    def getNodeCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("nodeCount", nodeCount)
    def getState: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("state", state)
    def getOfferingType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("offeringType", offeringType)
    def getRecurringCharges: ZIO[Any, AwsError, List[
      zio.aws.redshift.model.RecurringCharge.ReadOnly
    ]] = AwsError.unwrapOptionField("recurringCharges", recurringCharges)
    def getReservedNodeOfferingType
        : ZIO[Any, AwsError, zio.aws.redshift.model.ReservedNodeOfferingType] =
      AwsError.unwrapOptionField(
        "reservedNodeOfferingType",
        reservedNodeOfferingType
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ReservedNode
  ) extends zio.aws.redshift.model.ReservedNode.ReadOnly {
    override val reservedNodeId: Option[String] =
      scala.Option(impl.reservedNodeId()).map(value => value: String)
    override val reservedNodeOfferingId: Option[String] =
      scala.Option(impl.reservedNodeOfferingId()).map(value => value: String)
    override val nodeType: Option[String] =
      scala.Option(impl.nodeType()).map(value => value: String)
    override val startTime: Option[TStamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.redshift.model.primitives.TStamp(value))
    override val duration: Option[Integer] = scala
      .Option(impl.duration())
      .map(value => zio.aws.redshift.model.primitives.Integer(value))
    override val fixedPrice: Option[Double] =
      scala.Option(impl.fixedPrice()).map(value => value: Double)
    override val usagePrice: Option[Double] =
      scala.Option(impl.usagePrice()).map(value => value: Double)
    override val currencyCode: Option[String] =
      scala.Option(impl.currencyCode()).map(value => value: String)
    override val nodeCount: Option[Integer] = scala
      .Option(impl.nodeCount())
      .map(value => zio.aws.redshift.model.primitives.Integer(value))
    override val state: Option[String] =
      scala.Option(impl.state()).map(value => value: String)
    override val offeringType: Option[String] =
      scala.Option(impl.offeringType()).map(value => value: String)
    override val recurringCharges
        : Option[List[zio.aws.redshift.model.RecurringCharge.ReadOnly]] = scala
      .Option(impl.recurringCharges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.redshift.model.RecurringCharge.wrap(item)
        }.toList
      )
    override val reservedNodeOfferingType
        : Option[zio.aws.redshift.model.ReservedNodeOfferingType] = scala
      .Option(impl.reservedNodeOfferingType())
      .map(value => zio.aws.redshift.model.ReservedNodeOfferingType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ReservedNode
  ): zio.aws.redshift.model.ReservedNode.ReadOnly = new Wrapper(impl)
}
